@@ -58,15 +58,15 @@ _experiments_raw = {
         "semimajoraxis": 710141092212.9,  # in cm
         "prt_max": 0.0042081,  # values for petitradtrans test
         "prt_min": 0.00023373,  # values for petitradtrans test
-        "prt_mean": 0.00150488,  # values for petitradtrans test
+        "prt_sum": 0.31550672,  # values for petitradtrans test
     },
 }
 
 _experiments_nc = {
     "HD2_test_nc": {
         "tag": "HD2_test_nc",  # same as the filename (without extension)
-        "dlink": DLROOT + "36701961",
-        "md5": "73cdd7b938b25a173eeefb4262c6b6db",
+        "dlink": DLROOT + "37049866",
+        "md5": "4f9dba6f700e9e4c5fa27fae28510c50",
         "p_domain": [1e-5, 650],  # expected pressure domain in bar
         "times": [11000, 12000],  # expected timestamps in days
         "iters": [38016000, 41472000],
@@ -78,14 +78,14 @@ _experiments_nc = {
         "v_data": "V",
         "prt_max": 0.0042081,  # values for petitradtrans test
         "prt_min": 0.00023373,  # values for petitradtrans test
-        "prt_mean": 0.00150488,  # values for petitradtrans test
+        "prt_sum": 0.31550672,  # values for petitradtrans test
     },
 }
 
 _interface_data = {
     "prt_input_data": {
-        "dlink": DLROOT + "36704253",
-        "md5": "a7a1ecfa6764c0a4b55029da359f42d6",
+        "dlink": DLROOT + "36745209",
+        "md5": "01e64cc50d87d3c268e1861619b0cbf8",
         "line_species": ["H2O_Exomol_R_1"],
         "rayleigh_species": [],
         "continuum_opacities": [],
