@@ -11,6 +11,7 @@
 """
 from ..core import writer as wrt
 from ..core.const import VARNAMES as c
+import numpy as np
 
 
 def is_the_data_basic(dataset):
@@ -41,6 +42,14 @@ def is_the_data_basic(dataset):
 
     to_be_checked_coords = [c["lon"], c["lat"], c["Z"], c["time"]]
 
+    if "tag" not in dataset.attrs:
+        wrt.write_status(
+            "E-INFO",
+            "The dataset should contain a tag! "
+            + 'Add a tag using ds.attrs.update({"tag":"whatever"}).',
+        )
+        return False
+
     for dim in to_be_checked_coords:
         if dim not in data_coords:
             is_the_data_ok = False
@@ -141,6 +150,23 @@ def is_the_data_basic(dataset):
             + "therefore does not qualify as a basic GCM dataset.",
         )
 
+    if not is_the_data_ok:
+        return False
+
+    # Some additional checks that only work, if above already worked:
+
+    Z = dataset[c["Z"]].values
+    if (np.sort(Z) != Z[::-1]).any():
+        is_the_data_ok = False
+        wrt.write_status(
+            "E-INFO",
+            'The dataset "'
+            + str(dataset.attrs["tag"])
+            + '" is '
+            + "not correctly sorted from bottom to top"
+            + "therefore does not qualify as a basic GCM dataset.",
+        )
+
     return is_the_data_ok
 
 
